Sample Visualisation - FDSTools

Input & output

Sample data file:
(or drag a file onto this page)
Save image Save table Save page

Graph filtering options

Show sequences with at least:
reads
% of highest allele per marker
% of the marker's total reads
reads in both orientations
Marker(s) | ?
Mark with < | % of reads on one strand
Show negative alleles
Filter before noise correction
Show filtered data as 'Other sequences'

Table filtering options

Select sequences having at least:
reads
% of highest allele per marker
% of the marker's total reads
% correction*
% recovery*
reads in both orientations
*Of these criteria, at least one must be met
Clear manually added/removed

Display options

Graph width | px
Bar width | px
Marker spacing | px
Truncate sequences to | characters
Split markers
Common axis range ?
Sort STR alleles by length
Axis scale | Linear | Square root
Renderer | SVG | Canvas

Ready